@@ -21,13 +21,17 @@
 # -- Project information -----------------------------------------------------
 
 project = 'MRToolsTheme'
-copyright = '2020—2021, Michael Rippstein'
+copyright = '2020—2022, Michael Rippstein'
 author = 'Michael Rippstein'
 
 try:
-    from importlib.metadata import version                                            # noqa:E402
+    from importlib.metadata import (
+        version,
+    )                                            # noqa:E402
 except ModuleNotFoundError:
-    from importlib_metadata import version                                            # noqa:E402
+    from importlib_metadata import (
+        version,
+    )                                            # noqa:E402
 
 release = version('mrtoolstheme')
 # for example take major/minor
